
.. If you created a package, create one automodule per module in the package.

.. If your library file(s) are nested in a directory (e.g. /adafruit_foo/foo.py)
.. use this format as the module name: "adafruit_foo.foo"

.. automodule:: adafruit_displayio_layout.layouts.grid_layout
   :members:

.. automodule:: adafruit_displayio_layout.widgets.widget
   :members:
   :private-members:
   :member-order: bysource

.. automodule:: adafruit_displayio_layout.widgets.control
   :members:
   :member-order: bysource

.. automodule:: adafruit_displayio_layout.widgets.switch_round
   :members:
   :member-order: bysource
   :inherited-members:

.. inheritance-diagram:: adafruit_displayio_layout.widgets.switch_round

.. automodule:: adafruit_displayio_layout.widgets.icon_widget
   :members:
   :member-order: bysource
